@@ -15,19 +15,19 @@ for (i in c(6, 12, 24, 48, 96, 384, 1536)) {
 
     expect_error(
       check_plate(csv_file_1, well_id = "wells"),
-      "extraCol.csv is not a valid input file. Please review an example dataset."
+      regexp = "is not a valid input file"
     )
     expect_error(
       check_plate(csv_file_2, well_id = "wells"),
-      "twoPlatesExtraCol.csv is not a valid input file. Please review an example dataset."
-    )
+      regexp = "is not a valid input file"
+      )
     expect_error(
       check_plate(xlsx_file_1, well_id = "wells"),
-      "extraCol.xlsx is not a valid input file. Please review an example dataset."
+      regexp = "is not a valid input file"
     )
     expect_error(
       check_plate(xlsx_file_2, well_id = "wells"),
-      "twoPlatesExtraCol.xlsx is not a valid input file. Please review an example dataset."
+      regexp = "is not a valid input file"
     )
   })
 
@@ -37,36 +37,38 @@ for (i in c(6, 12, 24, 48, 96, 384, 1536)) {
 
     expect_error(
       check_plate(csv_file, well_id = "full"),
-      "Plate names cannot be the same as argument `well_id`."
+      regexp = "`well_id` value is invalid"
     )
     expect_error(
       check_plate(xlsx_file, well_id = "full"),
-      "Plate names cannot be the same as argument `well_id`."
+      regexp = "`well_id` value is invalid"
     )
   })
 
-  test_that("check_plate throws error when plate names are either empty or not unique", {
-    csv_file_1 <- paste0(path, "sameNames.csv")
-    xlsx_file_1 <- paste0(path, "sameNames.xlsx")
-    csv_file_2 <- paste0(path, "noName.csv")
-    xlsx_file_2 <- paste0(path, "noName.xlsx")
+  test_that("check_plate throws error when plate names are empty", {
+
+    csv_file_1 <- paste0(path, "noName.csv")
+    xlsx_file_1 <- paste0(path, "noName.xlsx")
 
     expect_error(
       check_plate(csv_file_1, well_id = "wells"),
-      "Verify that each plate in sameNames.csv has a unique name."
-    )
+      regexp = "Empty (blank or NA) plate name(s) found in", fixed = TRUE)
     expect_error(
       check_plate(xlsx_file_1, well_id = "wells"),
-      "Verify that each plate in sameNames.xlsx has a unique name."
-    )
+      regexp = "Empty (blank or NA) plate name(s) found in", fixed = TRUE)
+  })
+
+  test_that("check_plate throws error when plate names are not unique", {
+    csv_file_1 <- paste0(path, "sameNames.csv")
+    xlsx_file_1 <- paste0(path, "sameNames.xlsx")
+
     expect_error(
-      check_plate(csv_file_2, well_id = "wells"),
-      "Verify that each plate in noName.csv has a unique name."
-    )
+      check_plate(csv_file_1, well_id = "wells"),
+      regexp = "Duplicated plate name(s) found in", fixed = TRUE)
+
     expect_error(
-      check_plate(xlsx_file_2, well_id = "wells"),
-      "Verify that each plate in noName.xlsx has a unique name."
-    )
+      check_plate(xlsx_file_1, well_id = "wells"),
+      regexp = "Duplicated plate name(s) found in", fixed = TRUE)
   })
 
   test_that("check_plate throws error when row and column ids are empty or bad", {
@@ -99,22 +101,14 @@ for (i in c(6, 12, 24, 48, 96, 384, 1536)) {
     csv_file_2 <- paste0(path, "emptyRowName.csv")
     xlsx_file_2 <- paste0(path, "emptyRowName.xlsx")
 
-    expect_error(
-      check_plate(csv_file_1, well_id = "wells"),
-      "Verify row id(s) in badRowName.csv.", fixed = TRUE
-    )
-    expect_error(
-      check_plate(xlsx_file_1, well_id = "wells"),
-      "Verify row id(s) in badRowName.xlsx.", fixed = TRUE
-    )
-    expect_error(
-      check_plate(csv_file_2, well_id = "wells"),
-      "Verify row id(s) in emptyRowName.csv.", fixed = TRUE
-    )
-    expect_error(
-      check_plate(xlsx_file_2, well_id = "wells"),
-      "Verify row id(s) in emptyRowName.xlsx.", fixed = TRUE
-    )
+    expect_error(tidy_plate(csv_file_1, well_id = "wells"),
+                 regexp = "Verify row ids in ")
+    expect_error(tidy_plate(xlsx_file_1, well_id = "wells"),
+                 regexp = "Verify row ids in ")
+    expect_error(tidy_plate(csv_file_2, well_id = "wells"),
+                 regexp = "Verify row ids in ")
+    expect_error(tidy_plate(xlsx_file_2, well_id = "wells"),
+                 regexp = "Verify row ids in ")
   })
 
   test_that("check_plate throws error when column id(s) are empty or bad", {
@@ -123,22 +117,14 @@ for (i in c(6, 12, 24, 48, 96, 384, 1536)) {
     csv_file_2 <- paste0(path, "emptyColName.csv")
     xlsx_file_2 <- paste0(path, "emptyColName.xlsx")
 
-    expect_error(
-      check_plate(csv_file_1, well_id = "wells"),
-      "Verify column id(s) in badColName.csv.", fixed = TRUE
-    )
-    expect_error(
-      check_plate(xlsx_file_1, well_id = "wells"),
-      "Verify column id(s) in badColName.xlsx.", fixed = TRUE
-    )
-    expect_error(
-      check_plate(csv_file_2, well_id = "wells"),
-      "Verify column id(s) in emptyColName.csv.", fixed = TRUE
-    )
-    expect_error(
-      check_plate(xlsx_file_2, well_id = "wells"),
-      "Verify column id(s) in emptyColName.xlsx.", fixed = TRUE
-    )
+    expect_error(check_plate(csv_file_1, well_id = "wells"),
+                 regexp = "Verify column id(s) in ")
+    expect_error(check_plate(xlsx_file_1, well_id = "wells"),
+                 regexp = "Verify column id(s) in ")
+    expect_error(check_plate(csv_file_2, well_id = "wells"),
+                 regexp = "Verify column id(s) in ")
+    expect_error(check_plate(xlsx_file_2, well_id = "wells"),
+                 regexp = "Verify column id(s) in ")
   })
 }
 
@@ -175,11 +161,13 @@ test_that("check_plate throws an error when input file is non existant", {
 test_that("check_plate throws an error when input file is not csv or xlsx", {
   file <- "test_data/badFileType.txt"
 
-  expect_error(check_plate(file), "Unsupported file format. Please use CSV or Excel files.")
+  expect_error(check_plate(file),
+               regexp = "Unsupported file format. Please use CSV or Excel ")
 })
 
 test_that("check_plate throws an error when input file is empty", {
   csv_file <- "test_data/emptyFile.csv"
 
-  expect_error(check_plate(csv_file), "The input file or sheet is empty.")
+  expect_error(check_plate(csv_file, "emptyFile.csv"),
+               regexp = "file is empty")
 })
